@@ -24,6 +24,7 @@
 
 
 #include "config.h"
+
 #include <libgd/gd.h>
 
 #include "photos-empty-results-box.h"
@@ -51,7 +52,6 @@ struct _PhotosViewContainer
   GtkStack parent_instance;
   GdMainView *view;
   GtkListStore *model;
-  GtkTreePath *current_path;
   GtkWidget *error_box;
   GtkWidget *no_results;
   PhotosBaseManager *item_mngr;
@@ -109,13 +109,10 @@ photos_view_container_disconnect_view (PhotosViewContainer *self)
 
 
 static void
-photos_view_container_item_activated (PhotosViewContainer *self, const gchar * id, const GtkTreePath *path)
+photos_view_container_item_activated (PhotosViewContainer *self, const gchar * id)
 {
   GObject *object;
 
-  g_clear_pointer (&self->current_path, (GDestroyNotify) gtk_tree_path_free);
-
-  self->current_path = gtk_tree_path_copy (path);
   object = photos_base_manager_get_object_by_id (self->item_mngr, id);
 
   if (!photos_base_item_is_collection (PHOTOS_BASE_ITEM (object)) &&
@@ -407,7 +404,6 @@ photos_view_container_finalize (GObject *object)
 {
   PhotosViewContainer *self = PHOTOS_VIEW_CONTAINER (object);
 
-  g_clear_pointer (&self->current_path, (GDestroyNotify) gtk_tree_path_free);
   g_free (self->name);
 
   G_OBJECT_CLASS (photos_view_container_parent_class)->finalize (object);
@@ -520,20 +516,6 @@ photos_view_container_activate_result (PhotosViewContainer *self)
 }
 
 
-GtkTreePath *
-photos_view_container_get_current_path (PhotosViewContainer *self)
-{
-  return self->current_path;
-}
-
-
-GtkListStore *
-photos_view_container_get_model (PhotosViewContainer *self)
-{
-  return self->model;
-}
-
-
 const gchar *
 photos_view_container_get_name (PhotosViewContainer *self)
 {
